==> djaodjin-survey-0.8.1.tar.gz: djaodjin-survey-0.8.1/survey/urls/api/sample/update.py <==
# Copyright (c) 2023, DjaoDjin inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from ....api.sample import (SampleAPIView, SampleAnswersAPIView,
    SampleCandidatesAPIView, SampleFreezeAPIView, SampleRecentCreateAPIView,
    SampleRespondentsAPIView, SampleRespondentsIndexAPIView)
from ....compat import path

urlpatterns = [
    path('sample/<slug:sample>/freeze/<path:path>',
        SampleFreezeAPIView.as_view(), name='survey_api_sample_freeze'),
    path('sample/<slug:sample>/candidates/<path:path>',
        SampleCandidatesAPIView.as_view(), name='survey_api_sample_candidates'),
    path('sample/<slug:sample>/answers/<path:path>',
        SampleAnswersAPIView.as_view(), name='survey_api_sample_answers'),
    path('sample/<slug:sample>/respondents/<path:path>',
        SampleRespondentsAPIView.as_view(),
        name='survey_api_sample_respondents'),
    path('sample/<slug:sample>/respondents',
        SampleRespondentsIndexAPIView.as_view(),
        name='survey_api_sample_respondents_index'),
    path('sample/<slug:sample>',
        SampleAPIView.as_view(), name='survey_api_sample'),
    path('sample',
        SampleRecentCreateAPIView.as_view(), name='survey_api_sample_new'),
]

==> djaodjin-survey-0.9.3.tar.gz: djaodjin-survey-0.9.3/survey/urls/api/sample/update.py <==
# Copyright (c) 2023, DjaoDjin inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from ....api.sample import (SampleAPIView, SampleAnswersAPIView,
    SampleCandidatesAPIView, SampleFreezeAPIView, SampleRecentCreateAPIView,
    SampleRespondentsAPIView, SampleRespondentsIndexAPIView)
from ....api.matrix import SampleBenchmarksAPIView, SampleBenchmarksIndexAPIView
from ....compat import path

urlpatterns = [
    path('sample/<slug:sample>/freeze/<path:path>',
        SampleFreezeAPIView.as_view(), name='survey_api_sample_freeze'),
    path('sample/<slug:sample>/candidates/<path:path>',
        SampleCandidatesAPIView.as_view(), name='survey_api_sample_candidates'),
    path('sample/<slug:sample>/answers/<path:path>',
        SampleAnswersAPIView.as_view(), name='survey_api_sample_answers'),
    path('sample/<slug:sample>/benchmarks/<path:path>',
        SampleBenchmarksAPIView.as_view(), name='survey_api_sample_benchmarks'),
    path('sample/<slug:sample>/benchmarks',
        SampleBenchmarksIndexAPIView.as_view(),
        name='survey_api_sample_benchmarks_index'),
    path('sample/<slug:sample>/respondents/<path:path>',
        SampleRespondentsAPIView.as_view(),
        name='survey_api_sample_respondents'),
    path('sample/<slug:sample>/respondents',
        SampleRespondentsIndexAPIView.as_view(),
        name='survey_api_sample_respondents_index'),
    path('sample/<slug:sample>',
        SampleAPIView.as_view(), name='survey_api_sample'),
    path('sample',
        SampleRecentCreateAPIView.as_view(), name='survey_api_sample_list'),
]
